const FILE_INCLUSION_PATTERNS = [
  /\.\.\/\.\.\//,
  /\/etc\/passwd/,
  /\/proc\/self\/environ/,
  /\binclude\b.*\bhttp:\/\//i,
  /\binclude\b.*\bftp:\/\//i,
  /\.\.\\/,
  /[a-zA-Z]:\\/,
  /\/\w+\/\.\.\//,
  /\.\.\//,
  /etc\/shadow/,
  /root\/\.ssh/,
  /windows\/system32/,
  /boot.ini/,
  /\bfile\b:\/\/\/?/,
  /\bphp:\/\/input\b/,
  /\bdata\b:text\/plain;base64,/,
  /expect:\/\//,
  /phar:\/\//,
  /\bini_set\b/i,
  /\bopen_basedir\b/i,
  /\bload_file\b/i,
  /\binto\b\s+\boutfile\b/i,
  /(?:(?:[a-zA-Z]:|\/)[\w.\/\\-]+)+\.\w{2,4}/,
  /\.\.\//,
  /\.\.\\/,
  /\/etc\/passwd/,
  /\/etc\/shadow/,
  /\/proc\/self\/environ/,
  /\bfile:\/\/\b/,
  /\bphp:\/\/\b/,
  /<\?php/i,
  /data:.*?base64,/,
  /expect:\/\//i,
  /phar:\/\//i,
  /\bfile_put_contents\b/i,
  /\bexec\b/i,
  /\bsystem\b/i,
  /\bshell_exec\b/i,
  /\bpopen\b/i,
  /\bproc_open\b/i,
];

/**
 * Detects if there is a potential file inclusion vulnerability in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential file inclusion vulnerability is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common file inclusion patterns in the input string.
 * Patterns include directory traversal, remote file inclusion, and access to sensitive files and directories.
 *
 * @example
 * ```typescript
 * const input = "../../etc/passwd";
 * const isFileInclusion = detectFileInclusion(input);
 * console.log(isFileInclusion); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export function detectFileInclusion(input: string): boolean {
  return FILE_INCLUSION_PATTERNS.some((pattern) => pattern.test(input));
}
