const LDAP_INJECTION_PATTERNS = [
  /\(\|\|.*?\)/,
  /\(\&\&.*?\)/,
  /\b(&(.*?=.*?))\b/i,
  /\b(\|(.*?=.*?))\b/i,
  /\*\)/,
  /\(.*?=.*?\)/i,
  /\(\d+\)/,
  /\(\*\)/,
  /[\|\&\!]/,
  /\bobjectClass\b/i,
  /ldap:\/\/|ldaps:\/\//i,
  /\badmin\b/i,
  /OU=/i,
  /CN=/i,
  /DC=/i,
  /UID=/i,
  /userPassword/i,
  /\bpass\b/i,
  /\w+\s*=\s*['"][^'"]*['"]/,
  /\b\d{4,}\b/,
  /base64\s*,\s*[A-Za-z0-9+/=]+/,
  /\/\/\//,
  /(?:\b\w+\b\()|(?:\)\b\w+\b)/i,
];

/**
 * Detects if there is a potential LDAP injection in a given string.
 *
 * @param input - The string to analyze.
 * @returns `true` if a potential LDAP injection is detected, otherwise `false`.
 *
 * @remarks
 * This function uses a series of regular expressions to look for common LDAP injection patterns in the input string.
 * Patterns include logical operators, common LDAP attributes, and special characters used in LDAP queries.
 *
 * @example
 * ```typescript
 * const input = "(uid=admin)(&)";
 * const isLDAPInjection = detectLDAPInjection(input);
 * console.log(isLDAPInjection); // Output: true
 * ```
 *
 * @autor Andres Gutierrez Velez
 * @since 21/06/2024
 * @contact sr.willardkraft@gmail.com
 */
export function detectLDAPInjection(input: string): boolean {
  return LDAP_INJECTION_PATTERNS.some((pattern) => pattern.test(input));
}
